package main

import (
	"flag"
	"log"
	"os"
	"strconv"
	"time"

	"github.com/hashicorp/logutils"
	"github.com/prometheus/client_golang/prometheus"
)

func getEnvString(env, def string) (val string) { //nolint:deadcode
	val = os.Getenv(env)

	if val == "" {
		return def
	}

	return
}

func getEnvInt(env string, def int) (ret int) {
	val := os.Getenv(env)

	if val == "" {
		return def
	}

	ret, err := strconv.Atoi(val)
	if err != nil {
		log.Fatalf("[ERROR] Environment variable is not numeric: %v\n", env)
	}

	return
}

func initialize() {
	config.TimeZone, _ = time.LoadLocation("America/Chicago")
	config.TimeZoneUTC, _ = time.LoadLocation("UTC")

	var logLevel int

	flag.IntVar(&logLevel,
		"log",
		getEnvInt("LOG_LEVEL", 50),
		"(LOG_LEVEL)\nlog level")
	flag.IntVar(&config.WebSrvPort,
		"http-port",
		getEnvInt("HTTP_PORT", 8080),
		"(HTTP_PORT)\nlisten port for internal webserver")
	flag.StringVar(&config.WebSrvIP,
		"http-ip",
		getEnvString("HTTP_IP", "0.0.0.0"),
		"(HTTP_IP)\nlisten ip for internal webserver")

	flag.Parse()

	switch {
	case logLevel <= 20:
		config.Log.SetMinLevel(logutils.LogLevel("ERROR"))
	case logLevel > 20 && logLevel <= 40:
		config.Log.SetMinLevel(logutils.LogLevel("WARNING"))
	case logLevel > 40 && logLevel <= 60:
		config.Log.SetMinLevel(logutils.LogLevel("INFO"))
	case logLevel > 60 && logLevel <= 80:
		config.Log.SetMinLevel(logutils.LogLevel("DEBUG"))
	case logLevel > 80:
		config.Log.SetMinLevel(logutils.LogLevel("TRACE"))
	}
	log.SetOutput(config.Log)

	// print current configuration
	log.Printf("[DEBUG] configuration value set: LOG_LEVEL = %v\n", strconv.Itoa(logLevel))
	log.Printf("[DEBUG] configuration value set: HTTP_PORT = %v\n", strconv.Itoa(config.WebSrvPort))
	log.Printf("[DEBUG] configuration value set: HTTP_IP   = %v\n", config.WebSrvIP)

	prometheus.MustRegister(config.Prometheus.Temperature)
	log.Println("[DEBUG] Prometheus metrics registered")

	log.Println("[INFO] initialization complete")
}
